@@ -1,8 +1,13 @@
 JSweave <- function(file, ...) {
+  tex <- sub("[.][RrSs](nw|tex)$", ".tex", file)
   # Check for commands
   cmds <- Sys.which(c("uplatex", "dvipdfmx"))
   if (any(nchar(cmds) == 0)) {
     warning(gettextf("Vignette '%s' requires 'uplatex' and 'dvipdfmx'", basename(file)))
+    lines <- "\\documentclass{article}\\begin{document}
+    This document requires ``uplatex'' and ``dvipdfmx''
+    \\end{document}"
+    writeLines(lines, tex)
     return()
   }
   
@@ -10,7 +15,6 @@ JSweave <- function(file, ...) {
   # skip Sweave on the second run
   SweaveDVIPDFM(file, latex = "uplatex", dvipdfm = "echo", 
     	          encoding = "UTF-8")
-  tex <- sub("[.][RrSs](nw|tex)$", ".tex", file)
   SweaveDVIPDFM(tex, latex = "uplatex", dvipdfm = "dvipdfmx", 
 		  encoding = "UTF-8")
 }
